Trait hecs_schedule::context::Data [−][src]
Dynamically accessed static collection of values
Safety
Will type erase the given arguments by converting them to NonNull
Dynamically accessed static collection of values
Will type erase the given arguments by converting them to NonNull