Struct hecs_schedule::AllAccess
source ·
[−]pub struct AllAccess;Expand description
Marker type for a subworld which has access to the whole world
pub struct AllAccess;Marker type for a subworld which has access to the whole world