QueryOne

Struct QueryOne 

pub struct QueryOne<'a, Q: Query> { /* private fields */ }
Wraps the bulting QueryOne with a Result containing the entity and component instead of option

Implementations

Source

impl<'a, Q: Query> QueryOne<'a, Q>

pub fn get(&mut self) -> Result<Q::Item<'_>>

Get the query result, or return an error if the entity does not satisfy the query

Must be called at most once.

Panics if called more than once or if it would construct a borrow that clashes with another pre-existing borrow.