pub struct Schedule { /* private fields */ }Expand description
A shedule represents a collections of system which will run with effects in a determined order.
Implementations
Sourceimpl Schedule
impl Schedule
Sourcepub fn batch_info(&self) -> BatchInfo<'_>
pub fn batch_info(&self) -> BatchInfo<'_>
Returns information of how the schedule was split into batches
Sourcepub fn builder() -> ScheduleBuilder
pub fn builder() -> ScheduleBuilder
Creates a new ScheduleBuilder
Sourcepub fn execute_seq<D: IntoData<CommandBuffer>>(&mut self, data: D) -> Result<()>
pub fn execute_seq<D: IntoData<CommandBuffer>>(&mut self, data: D) -> Result<()>
Executes the systems inside the schedule sequentially using the provided data, which is a tuple of mutable references. Returns Err if any system fails.
A commandbuffer is always available and will be flushed at the end.
Sourcepub fn execute<D: IntoData<CommandBuffer> + Send + Sync>(
&mut self,
data: D,
) -> Result<()>
pub fn execute<D: IntoData<CommandBuffer> + Send + Sync>( &mut self, data: D, ) -> Result<()>
Executes the systems inside the schedule ina parallel using the provided data, which is a tuple of mutable references. Returns Err if any system fails
A commandbuffer is always available and will be flushed at the end.
Sourcepub fn cmd(&self) -> &CommandBuffer
pub fn cmd(&self) -> &CommandBuffer
Get a reference to the schedule’s cmd.
Sourcepub fn cmd_mut(&mut self) -> &mut CommandBuffer
pub fn cmd_mut(&mut self) -> &mut CommandBuffer
Get a mutable reference to the schedule’s cmd.