Struct hecs_schedule::SubWorldRaw [−][src]
pub struct SubWorldRaw<A, T> { /* fields omitted */ }Expand description
Implementations
Returns true if the subworld can access the borrow of T
Query the subworld. Fails if the query items are not compatible with the subworld
Query the subworld for a single entity. Wraps the hecs::NoSuchEntity error and provides the entity id
Get a single component from the world.
Wraps the hecs::NoSuchEntity error and provides the entity id
Splits the subworld further into a compatible subworld. Fails if not compatible