pub struct NamedSystem<F> { /* fields omitted */ }
A wrapper for providing a system with a name
Executes the by borrowing from context
Returns the system name. Used for debug purposes
Returns which data will be accessed
Wrap the system with a custom name
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer. Read more
Mutably dereferences the given pointer. Read more
Drops the object pointed to by the given pointer. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.