pub trait GenericWorld {
    fn try_query<Q: Query + Subset>(&self) -> Result<QueryBorrow<'_, Q>>;
fn try_query_one<Q: Query + Subset>(
        &self,
        entity: Entity
    ) -> Result<QueryOne<'_, Q>>;
fn try_get<C: Component>(&self, entity: Entity) -> Result<Ref<'_, C>>;
fn try_get_mut<C: Component>(&self, entity: Entity) -> Result<RefMut<'_, C>>;
fn reserve(&self) -> Entity; }
Trait for allowing function to work on both World and SubWorld

Required methods

Queries the world

Queries the world for a specific entity

Get a single component for an entity Returns the contextual result since hecs-schedule is required to be imported anyway

Get a single component for an entity Returns the contextual result since hecs-schedule is required to be imported anyway

Reserve an entity

Implementations on Foreign Types

Reserve an entity

Implementors