Type Definition hecs_schedule::SubWorldRef
source ·
[−]pub type SubWorldRef<'a, T> = SubWorldRaw<&'a World, T>;Expand description
Type alias for a subworld referencing the world by a reference
pub type SubWorldRef<'a, T> = SubWorldRaw<&'a World, T>;Type alias for a subworld referencing the world by a reference