Struct hecs_schedule::Schedule [−][src]
pub struct Schedule { /* fields omitted */ }Expand description
A shedule represents a collections of system which will run with effects in a determined order.
Implementations
Creates a new ScheduleBuilder
Executes the systems inside the schedule sequentially using the provided data, which is a tuple of mutable references. Returns Err if any system fails.
A commandbuffer is always available and will be flushed at the end.
Executes the systems inside the schedule ina parallel using the provided data, which is a tuple of mutable references. Returns Err if any system fails
A commandbuffer is always available and will be flushed at the end.