pub struct Schedule { /* fields omitted */ }
A shedule represents a collections of system which will run with effects in
a determined order.
Creates a new schedule from provided batches.
Executes the systems inside the schedule sequentially using the provided data, which
is a tuple of mutable references. Returns Err if any system fails
Executes the systems inside the schedule ina parallel using the provided data, which
is a tuple of mutable references. Returns Err if any system fails
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer. Read more
Mutably dereferences the given pointer. Read more
Drops the object pointed to by the given pointer. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.