Struct hecs_schedule::ScheduleBuilder[][src]

pub struct ScheduleBuilder { /* fields omitted */ }
Builder for incrementally constructing a schedule.

Implementations

Creates a new ScheduleBuilder

Add a system to the builder

Append all system from other into self, leaving other empty. This allows constructing smaller schedules in different modules and then joining them together. Work will be paralellized between the two schedules.

Flush the commandbuffer and apply the commands to the world

FLushes the commandbuffer and builds the schedule.