pub struct SubWorldRaw<A, T> { /* fields omitted */ }
Represents a borrow of the world which can only access a subset of
components (unless AllAccess is used).
This type allows for any reference kind, such as &World,
AtomicRef,
Ref, etc.
Type alises are provided for the most common usages, with SubWorld being
the one used by Schedule.
Splits the world into a subworld. No borrow checking is performed so may
fail during query unless guarded otherwise.
Returns true if the subworld can access the borrow of T
Returns true if the world satisfies the whole query
Query the subworld.
Panics if the query items are not a compatible subset of the subworld.
Query the subworld.
Fails if the query items are not compatible with the subworld
Query the subworld for a single entity.
Wraps the hecs::NoSuchEntity error and provides the entity id
Get a single component from the world.
If a mutable borrow is desired, use Self::query_one since the world is
only immutably borrowed.
Wraps the hecs::NoSuchEntity error and provides the entity id
Splits the subworld further into a compatible subworld. Fails if not
compatible
Returns a list of all component accesses
Returns true if U exists in Self
Queries the world for a specific entity
Get a single component for an entity
Returns the contextual result since hecs-schedule is required to be imported
anyway Read more
The type which View comes from
Splits from the containing superset
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer. Read more
Mutably dereferences the given pointer. Read more
Drops the object pointed to by the given pointer. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.