Trait hecs_schedule::GenericWorld[][src]

pub trait GenericWorld {
    fn try_query<Q: Query + Subset>(&self) -> Result<QueryBorrow<'_, Q>>;
fn try_query_one<Q: Query + Subset>(
        &self,
        entity: Entity
    ) -> Result<QueryOne<'_, Q>>;
fn try_get<C: Component>(&self, entity: Entity) -> Result<Ref<'_, C>>;
fn try_get_mut<C: Component>(&self, entity: Entity) -> Result<RefMut<'_, C>>;
fn try_get_column<C: Component>(&self) -> Result<Column<'_, C>>;
fn try_get_column_mut<C: Component>(&self) -> Result<ColumnMut<'_, C>>; }
Trait for allowing function to work on both World and SubWorld

Required methods

Queries the world

Queries the world for a specific entity

Get a single component for an entity Returns the contextual result since hecs-schedule is required to be imported anyway

Get a single component for an entity Returns the contextual result since hecs-schedule is required to be imported anyway

Borrow every component of type C

Borrow every component mutably of type C

Implementations on Foreign Types

Implementors